import requests
from pprint import pprint
from .start_up import URLS, AUTH


async def check_response(resp, topic=None):
    status = resp.status_code
    if status != 200:
        print(f"{topic or ''}request not successful: {status} - {resp.reason}")
    return resp


async def get_contacts():
    resp = requests.get(URLS["CONTACTS"], headers=AUTH)
    if await check_response(resp, topic="get_contacts"):
        [contact_ids.add(  c["contactId"]) for c in resp.json()]
        [contact_names.add(c["author"]["name"])     for c in resp.json()]
        return resp.json()


async def show_contacts():
    """
    lists your contacts
    """
    contacts = await get_contacts()
    print(f"  > your {len(contacts)} contacts:")
    for contact in contacts:
        print(f"{contact['contactId']:4}: {contact['author']['name']}")
        # print(f"{contact['contactId']:4}, {contact['alias']}, {contact['author']['name']}")


async def get_contact_id_by_alias(alias):
    contacts = await get_contacts()
    for contact in contacts:
        if contact['author']['name'] == alias:
            return str(contact["contactId"])


async def show_contacts_full_info():
    pprint(get_contacts())


async def get_pending_contacts():
    resp = requests.get(URLS["CONTACTS_PENDING"], headers=AUTH)
    if await check_response(resp, topic="get_pending_contacts"):
        return resp.json()


async def show_pending_contacts():
    """
    lists your peding contacts
    """
    pending_contacts = await get_pending_contacts()
    if not pending_contacts:
        print("  > no pending_contacts")
        return
    print(f"  > your {len(pending_contacts)} pending contacts:")
    for contact in pending_contacts:
        #print(f"{contact['contactId']:4}: {contact['alias']}")
        pprint(contact)


async def add_contact(briar_link, alias):
    """
    add contact with briar_link and alias
    """
    add_contact = {
        "link": briar_link,
        "alias": alias
    }
    resp = requests.post(URLS["CONTACTS_PENDING"], headers=AUTH, json=add_contact)
    if await check_response(resp, topic=f"add_contact {alias} - {briar_link}"):
        return resp.json()


async def get_own_briar_link():
    resp = requests.get(URLS["ADD_LINK"], headers=AUTH)
    if await check_response(resp, topic="get_own_briar_link"):
        return resp.json()


async def show_own_briar_link():
    """
    displays your own briar link
    """
    link = await get_own_briar_link()
    print(f"  > your own briar link: \n    {link['link']}")


contacts       = {}
contact_ids   = set()
contact_names = set()



"""briar cli-messenger for briar:headless"""

import asyncio
import types
from . import connections as conn
from . import contacts as cont
from . import messages as msgs
from . import repl
from .repl import prompt_session as ps
from .repl import help, exit_repl
from .contacts import show_contacts, show_pending_contacts, show_own_briar_link, add_contact
from .blogs import show_blog_posts


def main():
    loop = asyncio.get_event_loop()
    loop.run_until_complete(conn.probe_headless())
    loop.run_until_complete(show_contacts())
    loop.run_until_complete(chose_action())
    loop.close()


async def chat_with(contact_id):
    """
    chats with specific contact in 1:1 chat
    """
    if not contact_id.isdigit():
        contact_id = await cont.get_contact_id_by_alias(contact_id)
    with repl.patch_stdout():
        await msgs.show_history(contact_id)
        background_task = asyncio.create_task(conn.connect_websocket())
        try:
            await send_msgs(contact_id)
        finally:
            background_task.cancel()
        print("leaving chat..")


async def send_msgs(contact_id):
    repl.selected = "send_msgs"
    completes = {"/back"}
    completes.update(cont.contact_names)
    while True:
        msg_text = await ps.prompt_async(
            "msg: ",
            style=repl.prompt_style_chat,
            completer=repl.repl_completer(list(completes)),
        )
        if msg_text == "/back":
            break
        elif msg_text.startswith("/"):
            command, *args = msg_text[1:].split()
            if command in repl.implemented:
                # print(f"this now runs command: {command} with args: {args}")
                perform = repl.implemented.get(command)
                await perform(*args)

            else:
                print("sorry could not find this command..")

        elif len(msg_text) > 0:
            await msgs.send(contact_id, msg_text)


async def chose_action():
    repl.selected = "chose_action"
    completes = set(repl.implemented.keys())
    completes.update(cont.contact_names)
    while True:
        action = await ps.prompt_async(
            "com: ", 
            completer=repl.repl_completer(list(completes)),
            style=repl.prompt_style_commands,
        )
        command, *args = action.split()
        if command in repl.implemented:
            # print(f"this now runs command: {command} with args: {args}")
            perform = repl.implemented.get(command)
            await perform(*args)
        else:
            print("sorry could not find this command..")


if __name__ == "__main__":
    repl.implemented = {key: val for key, val in globals().items()
                        if isinstance(val, types.FunctionType)
                        and key not in repl.hidden}
    # print(repl.implemented.keys())
    main()



import asyncio
import json
import requests
import websockets
import colorful as col
from .start_up import URLS, AUTH, TOKEN
from . import messages as msgs


async def check_response(resp, topic=None):
    status = resp.status_code
    if status != 200:
        print(f"{topic or ''}request not successful: {status} - {resp.reason}")
    return resp


async def probe_headless():
    if await check_response(requests.get(URLS["CONTACTS"], headers=AUTH),
                      topic="probe headless if headless is running"):
        print(col.bold_chartreuse("connection to headless successful!"))
    else:
        print(col.bold_coral("could not connect to headless!"))


async def connect_websocket():
    async with websockets.connect(URLS["WS"]) as ws:
        await ws.send(TOKEN)
        await get_message_websocket(ws)


async def get_message_websocket(ws):
    while not ws.closed and not asyncio.get_event_loop().is_closed():
        message = await ws.recv()
        m = json.loads(message)
        if m['name'] == 'ConversationMessageReceivedEvent':
            print()  # line-break
            msgs.print_message(m['data'])
            print("", end='', flush=True)
    if not asyncio.get_event_loop().is_closed():
        asyncio.get_event_loop().create_task(get_message_websocket(ws))




import os
import errno
import getpass
from pathlib import Path
import colorful as col


def get_auth_token():
    AUTH_FILE = Path(f"/home/{getpass.getuser()}/.briar/auth_token")
    if not AUTH_FILE.exists():
        raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), AUTH_FILE)
    with open(AUTH_FILE) as txt:
        token = txt.read().strip()
        return {'Authorization': f'Bearer {token}'}, token


AUTH, TOKEN = get_auth_token()
HOST = "127.0.0.1"
PORT = 7000
API_VERSION = "v1"
URL_BASE = f'http://{HOST}:{PORT}/{API_VERSION}/'
APP_NAME = "briar_repl"
print(f"\nwelcome to {col.bold_chartreuse(APP_NAME)}!")
print("to list all functionality enter 'help'.\n")

URLS = {
    "BASE"             : URL_BASE,
    "CONTACTS"         : f"{URL_BASE}contacts",
    "CONTACTS_PENDING" : f"{URL_BASE}contacts/add/pending",
    "ADD_LINK"         : f"{URL_BASE}contacts/add/link",
    "MSGS"             : f"{URL_BASE}messages/",
    "BLOGS"            : f"{URL_BASE}blogs/posts",
    "WS"               : f'ws://{HOST}:{PORT}/{API_VERSION}/ws',
}



import requests
import datetime
from .start_up import URLS, AUTH


async def check_response(resp, topic=None):
    status = resp.status_code
    if status != 200:
        print(f"{topic or ''}request not successful: {status} - {resp.reason}")
    return resp


async def send(contact_id, text):
    resp = requests.post(URLS["MSGS"] + str(contact_id), headers=AUTH, json={'text': text})
    await check_response(resp, topic=f"send_message to {contact_id}")
    if resp.status_code == 200:
        await print_msg(resp.json())


async def get_history(contact_id):
    resp = requests.get(URLS["MSGS"] + str(contact_id), headers=AUTH)
    if await check_response(resp, topic="get_contacts"):
        return resp.json()


async def show_history(contact_id):
    history = await get_history(contact_id)
    if history:
        for message in history:
            await print_message(message)
            # print(message)


def get_timestamp(msg_time):
    # msg_time = datetime.datetime.fromtimestamp(msg_time / 1000).strftime('%Y-%m-%dT%H:%M:%S')
    msg_time = datetime.datetime.fromtimestamp(msg_time / 1000).strftime('%Y-%m-%d %H:%M')
    return msg_time


async def print_message(message):
    prefix = '> ' if message['local'] else ' <'
    time = get_timestamp(message['timestamp'])
    if 'text' in message:
        print(f"{time} {prefix} {message['text']}")


async def get_time(msg_time):
    # msg_time = datetime.datetime.fromtimestamp(msg_time / 1000).strftime('%Y-%m-%dT%H:%M:%S')
    msg_time = datetime.datetime.fromtimestamp(msg_time / 1000).strftime('%Y-%m-%d %H:%M')
    return msg_time


async def print_msg(message):
    prefix = '> ' if message['local'] else ' <'
    time = await get_time(message['timestamp'])
    if 'text' in message:
        print(f"{time} {prefix} {message['text']}")




import sys
from prompt_toolkit.patch_stdout import patch_stdout
from prompt_toolkit import PromptSession
from prompt_toolkit.styles import Style
from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
from prompt_toolkit.completion import WordCompleter
from prompt_toolkit.history import InMemoryHistory
from .start_up import APP_NAME


async def help():
    """
    lists implemented functions
    """
    for key, func in implemented.items():
        if key not in hidden:
            if func.__doc__:
                print(f"{key.rjust(32)}: {func.__doc__.strip()}")
            else:
                print(f"{key.rjust(15)}")


async def exit_repl():
    """
    exits the program
    """
    print("  exiting..")
    # asyncio.get_event_loop().close()
    sys.exit()


def repl_completer(word_list):
    return WordCompleter(word_list, ignore_case=True, match_middle=True)


def bottom_bar():
    return f'  > {APP_NAME} > {selected} '


selected = "start_up"
history = InMemoryHistory()
suggest = AutoSuggestFromHistory()

prompt_style_chat = Style.from_dict({"": "#cccccc",
                                     "bottom-toolbar": "#444444 bg:#222222",
                                     "bottom-toolbar.text": "#44aa44 bg:#eeeeee",
                                     })

prompt_style_commands = Style.from_dict({"": "#cccccc",
                                         "bottom-toolbar": "#444444 bg:#222222",
                                         "bottom-toolbar.text": "#4444dd bg:#eeeeee",
                                         })

PROMPT = 'msg: '
prompt_session = PromptSession(PROMPT,
                               history=history,
                               bottom_toolbar=bottom_bar,
                               style=prompt_style_commands,
                               )

implemented = {}
hidden = ["prompt", "pprint", "not_found", "try_int",
          "repl_completer", "send_msgs", "main",
          'connect_websocket', 'get_message_websocket',
          "chose_action",
          ]




import requests
from .start_up import URLS, AUTH


async def check_response(resp, topic=None):
    status = resp.status_code
    if status != 200:
        print(f"{topic or ''}request not successful: {status} - {resp.reason}")
    return resp


async def get_blog_posts():
    resp = requests.get(URLS["BLOGS"], headers=AUTH)
    if await check_response(resp, topic="get_blogs"):
        return resp.json()


async def show_blog_posts():
    """
    lists blog posts
    """
    posts = await get_blog_posts()
    print(f"  > showing {len(posts)} blog posts:")
    for blog_post in posts:
        print(f"{blog_post}")


async def post_blog_entry(blog_text):
    resp = requests.post(URLS["BLOGS"], headers=AUTH, json={"text": blog_text})
    if await check_response(resp, topic="post_blog_entry"):
        return resp.json()



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['briar_repl']

package_data = \
{'': ['*']}

setup(name='briar_repl',
      version='19.12.15',
      description='briar cli-messenger for briar:headless',
      author='fphemeral',
      author_email='fphemeral@i2pmail.org',
      url='https://code.briarproject.org/fphemeral/briar_repl',
      packages=packages,
      package_data=package_data,
     )
